========
pyspline
========

.. image:: https://codecov.io/github/StevenGolovkine/pyspline/graph/badge.svg?token=34ZUI8AZKL
    :target: https://codecov.io/github/StevenGolovkine/pyspline
    :alt: Coverage

.. image:: https://app.codacy.com/project/badge/Grade/404cd3e106d3446cb9e8acc259cb29c3
    :target: https://app.codacy.com/gh/StevenGolovkine/pyspline/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade
    :alt: Codacy


This package aims to re-implement the R package JOPS in Python.

References
==========

Eilers, P.H.C., Marx, B.D., 2021. Practical Smoothing: The Joys of P-splines.
Cambridge University Press, Cambridge. https://doi.org/10.1017/9781108610247
